<script type="text/javascript">
$(function () {
	Highcharts.setOptions({{option|safe}});
    $('#highcharts_container').highcharts({
        chart: {
            type: '{{type}}',
        },
        title: {
            text: '　',
        },
        xAxis: {
            categories: [
                       {% for item in categories %}
                       '{{item}}',
                       {% endfor %}
            ],
            crosshair: true
        },
        yAxis: {
            min: 0,
            title: {
                text: ''
            }
        },
        tooltip: {
            headerFormat: '<span style="font-size:10px">{point.key}</span><table>',
            pointFormat: '<tr><td style="color:{series.color};padding:0">{series.name}: </td>' +
                '<td style="padding:0"><b>{point.y}</b></td></tr>',
            footerFormat: '</table>',
            shared: true,
            useHTML: true
        },
        plotOptions: {
            column: {
                pointPadding: 0.2,
                borderWidth: 0
            }
        },
        series: [
                 {% for item in series %}
                 {
                     name: '{{item.name}}',
                     data: [
							{% for v in item.data %}
							{{v}},
							{% endfor %}
                            ]

                 }, 
                 {% endfor %}
		]
    });
});
</script>
<div id="highcharts_container" style="min-width: 310px; height: 400px; margin: 0 auto"></div>